@@ -5,7 +5,7 @@
 #' @param res A list structure containing all simulation results that are to be plotted.
 #'    The length of the list indicates the number of separate plots to make.
 #'    Each list entry corresponds to one plot and
-#'    needs to contain the following information/elements:
+#'    needs to contain the following information/elements: \cr
 #'    1. A data frame called "dat" or "ts". If the data frame is "ts" it is assumed to be
 #'    a time series and by default a line plot will be produced and labeled Time/Numbers.
 #'    For plotting, the data needs to be in a format with one column called xvals, one column yvals,
@@ -14,21 +14,24 @@
 #'    If a column 'varnames' exist, it is assumed the data is in the right format. Otherwise it will be transformed.
 #'    An optional column called IDvar can be provided for further grouping (i.e. multiple lines for stochastic simulations).
 #'    If plottype is 'mixedplot' an additional column called 'style' indicating line or point plot
-#'    for each variable is needed.
-#'    2. Meta-data for the plot, provided in the following variables:
-#'    optional: plottype - One of "Lineplot" (default is nothing is provided),"Scatterplot","Boxplot", "Mixedplot".
-#'    optional: xlab, ylab - Strings to label axes.
-#'    optional: xscale, yscale - Scaling of axes, valid ggplot2 expression, e.g. "identity" or "log10".
-#'    optional: xmin, xmax, ymin, ymax - Manual min and max for axes.
-#'    optional: legendtitle - Legend title, if NULL/not supplied no legend will be plotted.
-#'    optional: linesize - Width of line, numeric, i.e. 1.5, 2, etc. set to 1.5 if not supplied.
-#'    optional: title - A title for each plot.
+#'    for each variable is needed. \cr
+#'    2. Meta-data for the plot, provided in the following variables: \cr
+#'    optional: plottype - One of "Lineplot" (default is nothing is provided),"Scatterplot","Boxplot", "Mixedplot". \cr
+#'    optional: xlab, ylab - Strings to label axes. \cr
+#'    optional: xscale, yscale - Scaling of axes, valid ggplot2 expression, e.g. "identity" or "log10". \cr
+#'    optional: xmin, xmax, ymin, ymax - Manual min and max for axes. \cr
+#'    optional: makelegend - TRUE/FALSE, if legend should be added to plot. Assume true if not provided. \cr
+#'    optional: legendtitle - Legend title, if NULL/not supplied, default is used \cr
+#'    optional: legendlocation - if "right" is specified, top right. anythbing else or nothing will place it top left. \cr
+#'    optional: linesize - Width of line, numeric, i.e. 1.5, 2, etc. set to 1.5 if not supplied. \cr
+#'    optional: title - A title for each plot. \cr
 #'
 #' @return A plot structure for display in a Shiny UI.
 #' @details This function is called by the Shiny server to produce plots returned to the Shiny UI.
 #' Create plots run the simulation with default parameters just call the function:
 #' result <- simulate_basicbacteria()
 #' @author Andreas Handel
+#' @importFrom stats reshape
 #' @import ggplot2
 #' @importFrom gridExtra grid.arrange
 #' @export
@@ -80,7 +83,10 @@ generate_plots <- function(res)
       }
       else
       {
-        dat = tidyr::gather(rawdat, -xvals, value = "yvals", key = "varnames")
+        #using tidyr to reshape
+        #dat = tidyr::gather(rawdat, -xvals, value = "yvals", key = "varnames")
+        #using basic reshape function to reformat data
+        dat = stats::reshape(rawdat, varying = colnames(rawdat)[-1], v.names = 'yvals', timevar = "varnames", times = colnames(rawdat)[-1], direction = 'long', new.row.names = NULL); dat$id <- NULL
       }
 
       #code variable names as factor and level them so they show up right in plot - factor is needed for plotting and text
@@ -114,7 +120,7 @@ generate_plots <- function(res)
       {
         p1 = ggplot2::ggplot(dat, ggplot2::aes(x = xvals, y = yvals, color = varnames, linetype = varnames, shape = varnames) )
       }
-      if (!is.null(dat$IDvar))
+      else
       {
         p1 = ggplot2::ggplot(dat, ggplot2::aes(x = xvals, y = yvals, color = varnames, linetype = varnames, group = IDvar) )
       }
@@ -145,31 +151,49 @@ generate_plots <- function(res)
       {
         p3 = p2 + ggplot2::scale_x_continuous(trans = xscaletrans, limits=c(xmin,xmax), breaks = NULL, labels = NULL)
       }
-      if (plottype != 'Boxplot')
+      else
       {
         p3 = p2 + ggplot2::scale_x_continuous(trans = xscaletrans, limits=c(xmin,xmax))
         if (!is.null(resnow$xlab)) { p3 = p3 + ggplot2::xlab(resnow$xlab) }
       }
 
-      #apply y-axis
-      p5 = p3 + ggplot2::scale_y_continuous(trans = yscaletrans, limits=c(ymin,ymax))
-      if (!is.null(resnow$ylab)) { p5 = p5 + ggplot2::ylab(resnow$ylab) }
+      #apply y-axis and if provided, label
+      p4 = p3 + ggplot2::scale_y_continuous(trans = yscaletrans, limits=c(ymin,ymax))
+      if (!is.null(resnow$ylab)) { p4 = p4 + ggplot2::ylab(resnow$ylab) }
 
-      #do legend
-      if (is.null(resnow$legend))
+      #apply title if provided
+      if (!is.null(resnow$title))
       {
-        p6 = p5 + ggplot2::theme(legend.position="none")
+        p4 = p4 + ggplot2::ggtitle(resnow$title)
+      }
+
+      #modify overall theme
+      p5 = p4 + ggplot2::theme_bw(base_size = 18)
+
+
+      #do legend if TRUE or not provided
+      if (is.null(resnow$makelegend) || resnow$makelegend)
+      {
+        if (!is.null(resnow$legendlocation) && resnow$legendlocation == "right")
+        {
+             legendlocation = c(0.7,1)
+        }
+        else #default placement on left
+        {
+           legendlocation = c(0,1)
+        }
+
+        legendtitle = ifelse(is.null(resnow$legendtitle), "Variables", resnow$legendtitle)
+
+        p6 = p5 + ggplot2::theme(legend.key.width = grid::unit(3,"line")) + ggplot2::scale_colour_discrete(name  = legendtitle)      + ggplot2::scale_linetype_discrete(name = legendtitle)+ ggplot2::scale_shape_discrete(name = legendtitle)    + ggplot2::theme(legend.position = legendlocation, legend.justification=c(0,1), legend.key.width = unit(4,"line"), legend.background = element_rect(size=0.5, linetype="solid", colour ="black"))
       }
       else
       {
-        p6 = p5 + ggplot2::theme(legend.key.width = grid::unit(3,"line")) + ggplot2::scale_colour_discrete(name  = resnow$legend) + ggplot2::scale_linetype_discrete(name = resnow$legend) + ggplot2::scale_shape_discrete(name = resnow$legend)
+          p6 = p5 + ggplot2::theme(legend.position="none")
       }
 
-      #apply title if provided
-      if (!is.null(resnow$title)) { p6 = p6 + ggplot2::ggtitle(resnow$title) }
-
-      #modify overall theme and legend details
-      pfinal = p6 + ggplot2::theme_bw(base_size = 18) + ggplot2::theme(legend.position = c(0, 1), legend.justification=c(0,1), legend.key.width = unit(4,"line"), legend.background = element_rect(size=0.5, linetype="solid", colour ="black"))
+      #modify overall theme
+      pfinal = p6
 
       allplots[[n]] = pfinal
 
